'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var dateFns = require('date-fns');
var uaParserJs = require('ua-parser-js');

var isServer = typeof window === 'undefined';
var isDev = "development" === 'development';
var dateTimeFormat = 'dd.MM.yyyy - HH:mm';
var timeFormat = 'HH:mm';
var dateFormat = 'dd.MM.yyyy';
var getDateTimeFormat = function getDateTimeFormat(dateString) {
  switch (dateString) {
    case 'daytime':
      return dateTimeFormat;

    case 'day':
      return dateFormat;

    case 'time':
      return timeFormat;
  }
};
var uniquifyArray = function uniquifyArray(a) {
  if (!a || !Array.isArray(a)) return [];
  var seen = {};
  return a.filter(function (item) {
    if (!item) return false;
    return seen.hasOwnProperty(item) ? false : seen[item] = true;
  });
};
var uniquifyObjectArray = function uniquifyObjectArray(a, id) {
  if (!a || !Array.isArray(a)) return [];
  var seen = {};
  return a.filter(function (item) {
    if (!item) return false;
    if (!item[id]) return false;
    return seen.hasOwnProperty(item[id]) ? false : seen[item[id]] = true;
  });
};
var capitalizeString = function capitalizeString(string) {
  return string[0].toUpperCase() + string.slice(1, string.length);
};
var isValidDate = function isValidDate(d) {
  return d instanceof Date && !isNaN(d);
};
var getErrorMessage = function getErrorMessage(error) {
  if (typeof error === 'object') {
    return getErrorMessage(error[Object.keys(error)[0]]);
  }

  return error;
};
var cleanObject = function cleanObject(object) {
  var newObject = {};
  Object.keys(object).map(function (entry) {
    if (object[entry] !== 'N/A' && (typeof object[entry] === 'boolean' || Boolean(object[entry]))) {
      newObject[entry] = object[entry];
    }
  });
  return newObject;
};
var removeFromArray = function removeFromArray(items, array) {
  var newArray = Array.from(array);
  items.forEach(function (item) {
    newArray.splice(newArray.findIndex(function (val) {
      return val === item;
    }), 1);
  });
  return newArray;
};
var getBannerMessage = function getBannerMessage(settings) {
  var trialDate = new Date();
  trialDate.setDate(trialDate.getDate() + 5);

  if ((settings == null ? void 0 : settings.type) === 'trial' && new Date(settings == null ? void 0 : settings.dueDate) < trialDate) {
    return 'trialEnd';
  }

  return null;
};
var generateRandomString = function generateRandomString(_ref) {
  var length = _ref.length,
      _ref$withSymbols = _ref.withSymbols,
      withSymbols = _ref$withSymbols === void 0 ? false : _ref$withSymbols,
      _ref$withNumbers = _ref.withNumbers,
      withNumbers = _ref$withNumbers === void 0 ? true : _ref$withNumbers;
  var result = '';
  var specials = '!@#$%^&*';
  var numbers = '0123456789';
  var smallChars = 'abcdefghijklmnopqrstuvwxyz';
  var bigChars = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ';

  for (var i = 0; i < length / 4; i++) {
    if (withSymbols) {
      result += specials.charAt(Math.floor(Math.random() * specials.length));
    }

    if (withNumbers) {
      result += numbers.charAt(Math.floor(Math.random() * numbers.length));
    }

    result += smallChars.charAt(Math.floor(Math.random() * smallChars.length));
    result += bigChars.charAt(Math.floor(Math.random() * bigChars.length));
  }

  return result;
};
var getLanguages = function getLanguages(t) {
  return [{
    value: 'es',
    label: t('common:spanish')
  }, {
    value: 'en',
    label: t('common:english')
  }, {
    value: 'pt',
    label: t('common:portuguese')
  }, {
    value: 'de',
    label: t('common:german')
  }];
};
var formatDate = function formatDate(date, dateString, timezone) {
  if (!date || date === 'N/A') return date;
  var actualDate = dateFns.isDate(date) ? date : new Date(date);
  return dateFns.format(actualDate, getDateTimeFormat(dateString));
};
var parseDate = function parseDate(date, dateString) {
  return dateFns.parse(date, getDateTimeFormat(dateString), new Date());
};
var roundTo = function roundTo(number, decimals, asNumber) {
  var x = Math.pow(10, Number(decimals) + 1);
  if (asNumber) return Number((Number(number) + 1 / x).toFixed(decimals));
  return (Number(number) + 1 / x).toFixed(decimals);
};
var generateSlug = function generateSlug(text) {
  return text.toString().normalize('NFD').replace(/[\u0300-\u036f]/g, '').toLowerCase().trim().replace(/\s+/g, '-').replace(/[^\w-]+/g, '').replace(/--+/g, '-');
};
var getSubdomain = function getSubdomain(url) {
  var _process$env$VERCEL_G, _process$env$VERCEL_G2, _process$env$VERCEL_G3;

  if (url === 'inventhora.com' || url.indexOf('localhost') === 0 && url.indexOf('inventhora') === -1) {
    return process.env.DEFAULT_SUBDOMAIN;
  }

  var currentBranch = (_process$env$VERCEL_G = process.env.VERCEL_GITHUB_COMMIT_REF) == null ? void 0 : (_process$env$VERCEL_G2 = _process$env$VERCEL_G.toLowerCase()) == null ? void 0 : (_process$env$VERCEL_G3 = _process$env$VERCEL_G2.replace('/', '-')) == null ? void 0 : _process$env$VERCEL_G3.replace('_', '-');

  if (currentBranch !== 'master') {
    return 'testing';
  }

  return url.split('.')[0];
};
var parseNumber = function parseNumber(number) {
  if (number === null || number === undefined || number === '') return null;
  if (typeof number === 'number') return number;
  return Number(number.replace(',', '.'));
};
var removeFromObjectArray = function removeFromObjectArray(array, key, value) {
  var newArray = Array.from(array);
  newArray.splice(newArray.findIndex(function (item) {
    return item[key] === value;
  }), 1);
  return newArray;
};
var getObjectKeyByString = function getObjectKeyByString(o, s) {
  s = s.replace(/\[(\w+)\]/g, '.$1'); // convert indexes to properties

  s = s.replace(/^\./, ''); // strip a leading dot

  var a = s.split('.');

  for (var i = 0, n = a.length; i < n; ++i) {
    var k = a[i];
    if (!Boolean(o)) return null;

    if (k in o) {
      o = o[k];
    } else {
      return;
    }
  }

  return o;
};
var constructDimensionString = function constructDimensionString(dimensions, lengthUnit) {
  if (!dimensions.width && !dimensions.depth) {
    return "" + dimensions.height + lengthUnit + ".";
  }

  if (!dimensions.depth) {
    return dimensions.height + "x" + dimensions.width + lengthUnit + ".";
  }

  return dimensions.height + "x" + dimensions.width + "x" + dimensions.depth + lengthUnit + ".";
};
var createProductFullName = function createProductFullName(_ref2) {
  var product = _ref2.product,
      weightUnit = _ref2.weightUnit,
      lengthUnit = _ref2.lengthUnit,
      t = _ref2.t;
  var name = product.name,
      material = product.material,
      color = product.color,
      weight = product.weight,
      dimensions = product.dimensions,
      quantity = product.quantity;
  var baseString = name;

  if (material) {
    baseString = baseString + " " + material;
  }

  if (color) {
    baseString = baseString + " " + color;
  }

  if (weight) {
    baseString = baseString + " " + weight + weightUnit + ".";
  }

  if (dimensions) {
    baseString = baseString + " " + constructDimensionString(dimensions, lengthUnit);
  }

  if (quantity) {
    baseString = baseString + " " + quantity + t('common:pieces', {
      count: quantity
    });
  }

  return baseString;
};
var isMobile = function isMobile(ctx) {
  var uaParser = new uaParserJs.UAParser(ctx.req ? ctx.req.headers['user-agent'] : navigator.userAgent);
  var device = uaParser.getDevice().type;
  return device === 'mobile' || device === 'tablet';
};

exports.capitalizeString = capitalizeString;
exports.cleanObject = cleanObject;
exports.constructDimensionString = constructDimensionString;
exports.createProductFullName = createProductFullName;
exports.dateFormat = dateFormat;
exports.dateTimeFormat = dateTimeFormat;
exports.formatDate = formatDate;
exports.generateRandomString = generateRandomString;
exports.generateSlug = generateSlug;
exports.getBannerMessage = getBannerMessage;
exports.getDateTimeFormat = getDateTimeFormat;
exports.getErrorMessage = getErrorMessage;
exports.getLanguages = getLanguages;
exports.getObjectKeyByString = getObjectKeyByString;
exports.getSubdomain = getSubdomain;
exports.isDev = isDev;
exports.isMobile = isMobile;
exports.isServer = isServer;
exports.isValidDate = isValidDate;
exports.parseDate = parseDate;
exports.parseNumber = parseNumber;
exports.removeFromArray = removeFromArray;
exports.removeFromObjectArray = removeFromObjectArray;
exports.roundTo = roundTo;
exports.timeFormat = timeFormat;
exports.uniquifyArray = uniquifyArray;
exports.uniquifyObjectArray = uniquifyObjectArray;
//# sourceMappingURL=inventhora-utils.cjs.development.js.map
